import { jsx as _jsx } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import * as React from "react";
import PropTypes from "prop-types";
import { useMeasure } from "./Hooks/use-measure";
const flexClPp = [100, 50, 33.333, 25, 20];
//缺省breaks ： <LineColumn column={2} breaks={[288, 520]}
//可以安排几个列
const defaultBreakOf = [
    [336],
    [336, 880],
    [314, 628, 942],
    [292, 584, 876, 1168],
    [240, 480, 720, 960, 1200],
];
/**
 * 布局组件：最多5列的。
 * 1，2列，3列，4列，5列。
 * 父辈窗口屏幕宽度就算再大，也是只安排2 或3 或4 或5 个列的，布局思路。
 为了整齐对齐的需要；
 * 特别注意！！ LineColumn底下的子组件第一个div或者<tag>的样式请不要使用padding和margin的设置px; 就算要设置所有儿子也必须保持一致。
 * 用InputLineL来代替InputGroup因为其内部section默认padding:48px 20px所以会导致布局宽度分配不一致。
 * fitable注入给儿子组件报错问题：儿子不要是不可接受fitable参数的原生Tag;
 * 实际经验 测试调整column={5} breaks={[170,290,390,490,750]}取值，根据目标编辑宽度以及实际的DIV容器宽度判定。
 * 【有问题的是LineColumn】没办法穿透<>和<React.Fragment>俩个空白语法标签；儿子不能放在这两个底下。
 */
export const LineColumn = ({ column = 2, children, breaks = defaultBreakOf[column - 1], ...other }) => {
    const reflc = React.useRef(null);
    const width = useMeasure(reflc)?.width;
    // const { bounds } = useMeasure(reflc);
    // const { width,  } = bounds;
    const [fitable, setFitable] = React.useState(true);
    //最适合搞几个列。
    const [suitableCls, setSuitableCls] = React.useState(2);
    //【不能改掉的】@ @注意！ useLayoutEffect； 假如改成useEffect无法正常打印预览列{suitableCls}宽{width}的连两个数字前面哪个不对了!。
    React.useLayoutEffect(() => {
        let i = 0;
        for (; i < column; i++)
            if (width < breaks[i])
                break;
        setSuitableCls(i < 1 ? 1 : i);
        setFitable(i > 0);
    }, [width, column, setSuitableCls, setFitable, breaks]);
    //console.log("Render fitable=",fitable,"suitableCls=",suitableCls);
    //有效的儿子组件:
    const kids = React.Children.toArray(children).filter(child => {
        if (!React.isValidElement(child))
            throw new Error("literal text must be wrapped in <></> tag or Components");
        return child;
    });
    const sonCount = kids.length;
    const lineSum = Math.ceil(sonCount / suitableCls);
    if (column > 5 || column < 1)
        throw new Error("number of columns must >=1 and <=5");
    //必须加一层div{{ position: 'relative' }}，后面给出的父辈Div宽度width才对的。
    return (_jsx("div", { ref: reflc, style: { position: 'relative' }, children: suitableCls > 1 ?
            new Array(lineSum).fill(null).map((one, row) => (_jsx("div", { css: {
                    display: 'flex',
                    justifyContent: 'space-around',
                    alignItems: 'center'
                }, children: new Array(suitableCls).fill(null).map((each, clm) => {
                    if (kids[row * suitableCls + clm]) {
                        return React.cloneElement(kids[row * suitableCls + clm], {
                            style: { flex: `1 1 ${flexClPp[suitableCls - 1]}%` }
                        });
                    }
                    else
                        return _jsx("div", { css: { flex: `1 1 ${flexClPp[suitableCls - 1]}%` } }, clm);
                }) }, row)))
            :
                kids.map((one, row) => React.cloneElement(one, {
                    fitable: fitable
                })) }));
};
LineColumn.displayName = "LineColumn";
LineColumn.propTypes = {
    children: PropTypes.node
};
//# sourceMappingURL=LineColumn.js.map